@@ -1,6 +1,6 @@
-/* $Id: asc2bin.c 616 2005-08-19 20:11:01Z bruce $ */
+/* $Id: asc2bin.c 655 2005-12-18 22:15:26Z bruce $ */
 #include "base64.h"
-const char base64_asc2bin[256] = {
+const signed char base64_asc2bin[256] = {
   -1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, /* 0-15 */
   -1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, /* 16-31 */
   -1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,62,-1,-1,-1,63, /* 32-47 */
