@@ -1,4 +1,4 @@
-/* $Id: md5.c 646 2005-12-01 22:07:11Z bruce $ */
+/* $Id: md5.c 668 2006-02-19 05:58:04Z bruce $ */
 /* md5.c - Functions to compute MD5 message digest of files or memory blocks
    according to the definition of MD5 in RFC 1321 from April 1992.
    Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
@@ -27,7 +27,6 @@
 #include <string.h>
 
 #include "sysdeps.h"
-#include "hmac.h"
 #include "md5.h"
 
 #ifdef ENDIAN_MSB
@@ -218,7 +217,7 @@ md5_process_bytes (buffer, len, ctx)
     }
 
   /* Process available complete blocks.  */
-  if (len > 64)
+  if (len >= 64)
     {
       md5_process_block (buffer, len & ~63, ctx);
       buffer = (const char *) buffer + (len & ~63);
@@ -404,22 +403,6 @@ md5_process_block (buffer, len, ctx)
   ctx->D = D;
 }
 
-static void md5_process_bytes_wrapper(void* ctx,
-				      unsigned const char* bytes,
-				      unsigned long len)
-{
-  md5_process_bytes(bytes, len, ctx);
-}
-
-const struct hmac_control_block hmac_md5 = {
-  sizeof(struct md5_ctx),
-  128/8,
-  64,
-  (hmac_init_fn)md5_init_ctx,
-  (hmac_update_fn)md5_process_bytes_wrapper,
-  (hmac_finalize_fn)md5_finish_ctx
-};
-
 #ifdef SELFTEST_MAIN
 #include <stdio.h>
 #include "str/str.h"
@@ -439,18 +422,6 @@ static void MDString(const char* s)
   printf("\n");
 }
 
-static void HMACTest(const char* key, const char* data)
-{
-  const str key_str = { (char*)key, strlen(key), 0 };
-  const str data_str = { (char*)data, strlen(data), 0 };
-  unsigned char digest[128/8];
-  unsigned i;
-  hmac(&hmac_md5, &key_str, &data_str, digest);
-  printf("HMAC (%d,%d) = ", key_str.len, data_str.len);
-  for (i = 0; i < sizeof digest; ++i) printf("%02x", digest[i]);
-  printf("\n");
-}
-
 int main(void)
 {
   printf("MD5 test suite:\n");
@@ -463,17 +434,6 @@ int main(void)
   
   MDString("1234567890123456789012345678901234567890"
 	   "1234567890123456789012345678901234567890");
-
-  /* Test vectors from RFC 2104 */
-  HMACTest("\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b",
-	   "Hi There");
-  HMACTest("Jefe", "what do ya want for nothing?");
-  HMACTest("\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa\xaa",
-	   "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd"
-	   "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd"
-	   "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd"
-	   "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd"
-	   "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd");
   return 0;
 }
 #endif
@@ -486,7 +446,4 @@ MD5 ("message digest") = f96b697d7cb7938d525a2f31aaf161d0
 MD5 ("abcdefghijklmnopqrstuvwxyz") = c3fcd3d76192e4007dfb496cca67e13b
 MD5 ("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789") = d174ab98d277d9f5a5611c2c9f419d9f
 MD5 ("12345678901234567890123456789012345678901234567890123456789012345678901234567890") = 57edf4a22be3c955ac49da2e2107b67a
-HMAC (16,8) = 9294727a3638bb1c13f48ef8158bfc9d
-HMAC (4,28) = 750c783e6ab0b503eaa86e310a5db738
-HMAC (16,50) = 56be34521d144c88dbb8c733f0e8b3f6
 #endif
