@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: ibuf_getstr.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "ibuf.h"
 #include "str/str.h"
 
 /** Read a line from the \c ibuf into a dynamic string. */
