@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: ibuf_getu.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "ibuf.h"
 
 /** Read an unsigned long from the \c ibuf */
 int ibuf_getu(ibuf* in, unsigned long* data)
@@ -9,7 +10,7 @@ int ibuf_getu(ibuf* in, unsigned long* data)
   *data = 0;
   chars = 0;
   while (ibuf_peek(in, &ch) && ch >= '0' && ch <= '9') {
-    *data = (*data * 10) + ch - 0;
+    *data = (*data * 10) + ch - '0';
     ibuf_getc(in, &ch);
     chars = 1;
   }
