@@ -1,5 +1,6 @@
+/* $Id: ibuf_init.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <unistd.h>
-#include "iobuf.h"
+#include "ibuf.h"
 
 /** Initialize an \c ibuf from an already-opened file descriptor. */
 int ibuf_init(ibuf* in, int fd, ibuf_fn fn, unsigned flags, unsigned bufsize)
