@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: ibuf_peek.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "ibuf.h"
 
 /** Retrieve the next character in the \c ibuf without advancing the
     current read position. */
