@@ -1,6 +1,7 @@
+/* $Id: ibuf_refill.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <errno.h>
 #include <unistd.h>
-#include "iobuf.h"
+#include "ibuf.h"
 
 static const char errmsg[] = "ibuf_refill called with non-empty buffer!\n";
 
