@@ -1,7 +1,8 @@
+/* $Id: ibuf_seek.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <errno.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include "iobuf.h"
+#include "ibuf.h"
 
 /** Set the effective read position. */
 int ibuf_seek(ibuf* in, unsigned offset)
