@@ -1,5 +1,6 @@
+/* $Id: ibuf_stdin.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <unistd.h>
-#include "iobuf.h"
+#include "ibuf.h"
 
 static char buffer[4096];
 
