@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: ibuf_tell.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "ibuf.h"
 
 /** Look up the current effective read position. */
 unsigned ibuf_tell(ibuf* in)
