@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: obuf_close.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "obuf.h"
 
 /** Flush and close the \c obuf */
 int obuf_close(obuf* out)
