@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: obuf_digits.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "obuf.h"
 
 const char obuf_dec_digits[10] = "0123456789";
 const char obuf_hex_lcase_digits[16] = "0123456789abcdef";
