@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: obuf_endl.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "obuf.h"
 
 /** Write a newline to the \c obuf and flush it. */
 int obuf_endl(obuf* out)
