@@ -1,6 +1,7 @@
+/* $Id: obuf_flush.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <errno.h>
 #include <unistd.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Write all pending data in the \c obuf to the file descriptor. */
 int obuf_flush(obuf* out)
