@@ -1,5 +1,6 @@
+/* $Id: obuf_init.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <unistd.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Initialize an \c obuf from an already-opened file descriptor. */
 int obuf_init(obuf* out, int fd, obuf_fn fn, unsigned flags, unsigned bufsize)
