@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: obuf_open.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "obuf.h"
 
 /** Initialize an \c obuf by opening a file for writing. */
 int obuf_open(obuf* out, const char* filename, int oflags, int mode,
