@@ -1,5 +1,6 @@
+/* $Id: obuf_put3s.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Write 3 C strings to the \c obuf */
 int obuf_put3s(obuf* out, const char* s1, const char* s2, const char* s3)
