@@ -1,4 +1,5 @@
-#include "iobuf.h"
+/* $Id: obuf_putc.c 616 2005-08-19 20:11:01Z bruce $ */
+#include "obuf.h"
 
 /** Write a single character to the \c obuf */
 int obuf_putc(obuf* out, char ch)
