@@ -1,5 +1,6 @@
+/* $Id: obuf_putsflush.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Write a C string to the \c obuf and flush it. */
 int obuf_putsflush(obuf* out, const char* str)
