@@ -1,7 +1,8 @@
+/* $Id: obuf_seek.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <errno.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Set the effective write position. */
 int obuf_seek(obuf* out, unsigned offset)
