@@ -1,6 +1,7 @@
+/* $Id: obuf_sync.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <errno.h>
 #include <unistd.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Flush the \c obuf and then \c fsync the file descriptor. */
 int obuf_sync(obuf* out)
