@@ -1,5 +1,4 @@
-#include <stdlib.h>
-
+/* $Id: debug.c 616 2005-08-19 20:11:01Z bruce $ */
 #include "msg.h"
 
 void msg_debug(int bit,
@@ -9,10 +8,3 @@ void msg_debug(int bit,
   if (msg_debug_bits & bit)
     msg_common("Debug", a, b, c, d, e, f, showsys);
 }
-
-void msg_debug_init(void)
-{
-  const char* env;
-  if ((env = getenv("MSG_DEBUG")) != 0)
-    msg_debug_bits = strtoul(env, 0, 10);
-}
