@@ -1,3 +1,4 @@
+/* $Id: ipv6.h 616 2005-08-19 20:11:01Z bruce $ */
 #ifndef NET__IPV6__H__
 #define NET__IPV6__H__
 
@@ -8,7 +9,10 @@
 @{ */
 
 /** IPv6 address structure. */
-typedef struct { uint8 addr[16]; } ipv6addr;
+typedef struct {
+    /** 128-bit IPv4 address, represented as 16 8-bit \c unsigned \c chars. */
+  uint8 addr[16];
+} ipv6addr;
 /** IPv6 port number. */
 typedef uint16 ipv6port;
 
@@ -19,6 +23,6 @@ extern const char* ipv6_scan(const char* s, ipv6addr* addr);
 extern const char* ipv6_format(const ipv6addr* addr);
 extern unsigned fmt_ipv6addr(char* buffer, const ipv6addr* addr);
 
-/* @} */
+/** @} */
 
 #endif
