@@ -1,19 +1,20 @@
+/* $Id: match.c 639 2005-11-21 04:43:14Z bruce $ */
 /* path/match.c - Filename matching utility.
- * Copyright (C) 2001  Bruce Guenter <bruceg@em.ca>
+ * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 #include <errno.h>
 #include <string.h>
@@ -183,7 +184,7 @@ MAIN
   match("*.o*", 0);
   match("*.[eo]", 0);
   match("t*", 0);
-  match("*.[~o]*", 0);
+  match("*.[!o]*", 0);
 }
 #endif
 #ifdef SELFTEST_EXP
@@ -204,6 +205,6 @@ test
 test.exp
 test.o
 test.out
-*.[~o]* 0 => 1
+*.[!o]* 0 => 1
 test.exp
 #endif
