@@ -1,7 +1,9 @@
+/* $Id: iter_start.c 616 2005-08-19 20:11:01Z bruce $ */
 #include "iter.h"
+#include "str.h"
 
 /** Start (initialize) a striter. */
-void striter_start(striter* iter, const str* s, char sep)
+void striter_start(striter* iter, const struct str* s, char sep)
 {
   iter->str = s;
   iter->start = 0;
