@@ -1,8 +1,11 @@
+/* $Id: vpwentry_export.c 621 2005-08-19 22:38:58Z bruce $ */
 #include "vpwentry.h"
 #include "str/str.h"
 
 static int str_catunul(str* result, unsigned long u)
 {
+  if (u == (unsigned)-1)
+    return str_catb(result, "-", 2);
   return str_catu(result, u) && str_catc(result, 0);
 }
 
